Contributing guidelines for NuRadioReco

NuRadioReco is intended as community based reconstruction software for radio neutrino detectors. 
Everyone is invited to contribute. 

If you intend to contribute significantly to NuRadioReco, please contact @anelles and @cg-laser so that we
are informed about ongoing activities. 
